@@ -1,4 +1,5 @@
 from datetime import datetime
+from typing import Literal
 
 import typer
 
@@ -66,7 +67,7 @@ def init_cmd(
         typer.echo("📝 README.md created")
 
     # 5. Save session token if provided
-    token_path = utils.TOKEN_PATH
+    token_path = utils.ENV_PATH
     if not token:
         typer.echo("⚠️ No session token provided (set it later with 'ecd set-token')")
     elif token_path.exists() and not force:
@@ -79,20 +80,24 @@ def init_cmd(
 @app.command("set-token")
 def set_token_cmd(
     token: str = typer.Argument(..., help="Session token to access puzzle inputs"),
+    force: bool = typer.Option(False, "--force", "-f", help="Overwrite existing token"),
 ) -> None:
     """Set the session token to operate with Everybody Codes webpage."""
-    utils.set_token(token)
-    typer.echo("🔑 Session token saved to /home/.config/ecd/token")
+    token_path = utils.ENV_PATH
+    if token_path.exists() and not force:
+        typer.echo("⚠️ Session token file already exists (use --force to overwrite).")
+    else:
+        utils.set_token(token, force)
+        typer.echo(f"🔑 Session token saved to {token_path}")
 
 
 @app.command("pull")
 def pull_cmd(
     quest: int = typer.Argument(..., help="Quest number (e.g. 3)"),
     year: int = typer.Option(datetime.now().year, "--year", "-y", help="Event year"),
-    part: int = typer.Option(1, "--part", "-p", help="Puzzle part (1, 2, or 3)"),
     force: bool = typer.Option(False, "--force", "-f", help="Overwrite existing files"),
 ) -> None:
-    """Download input data for a given quest and create local structure."""
+    """Download available input data for a given quest and create local structure."""
 
     # 0. Locate base directory
     base_dir = utils.find_base()
@@ -104,12 +109,11 @@ def pull_cmd(
         )
         raise typer.Exit(1)
 
-    # 2. Download the input for the given part
+    # 2. Download the available input
     try:
-        input_text = utils.download_input(year, quest, part)
+        input_dict = utils.download_input(year, quest)
     except Exception as e:
         typer.echo(f"❌ Failed to fetch input: {e}")
-        typer.echo("ℹ️ Maybe ")
         raise typer.Exit(1)
 
     # 3. Prepare directory structure
@@ -118,36 +122,43 @@ def pull_cmd(
     # 4. Create solution.py if missing
     solution_file = quest_dir / "solution.py"
     if solution_file.exists() and not force:
-        typer.echo("⚠️ solution.py already exists (use --force to overwrite).")
+        typer.echo(
+            "⚠️ The solution python file already exists (use --force to overwrite)."
+        )
     else:
         utils.create_solution(quest_dir, force)
         typer.echo("🧩 Created solution.py")
 
-    # 5. Save input
-    input_file = quest_dir / f"input/input_p{part}.txt"
-    if input_file.exists() and not force:
-        typer.echo("⚠️ Input file already exists (use --force to overwrite).")
-    else:
-        input_file.write_text(input_text, encoding="utf-8")
-        typer.echo(f"📥 Saved input for quest {quest:02d} part {part}.")
+    for part, input in input_dict.items():
+        # 5. Save available inputs
+        input_file = quest_dir / f"input/input_p{part}.txt"
+        if input_file.exists() and not force:
+            typer.echo(
+                f"⚠️ Input file for part {part} already exists (use --force to overwrite)."
+            )
+        else:
+            input_file.write_text(input, encoding="utf-8")
+            typer.echo(f"📥 Saved input for quest {quest:02d} part {part}.")
 
-    # 6. Ensure empty test file exists
-    test_file = quest_dir / f"test/test_p{part}.txt"
-    if test_file.exists() and not force:
-        typer.echo("⚠️ Test file already exists (use --force to overwrite).")
-    else:
-        test_file.touch(exist_ok=True)
+        # 6. Ensure empty test file exists
+        test_file = quest_dir / f"test/test_p{part}.txt"
+        if test_file.exists() and not force:
+            typer.echo(
+                f"⚠️ Test file for part {part} already exists (use --force to overwrite)."
+            )
+        else:
+            test_file.touch(exist_ok=True)
 
-    typer.echo(
-        f"✅ Quest {quest:02d} (Part {part}) ready at {solution_file.relative_to(base_dir)}"
-    )
+    typer.echo(f"✅ Quest {quest:02d} ready at {solution_file.relative_to(base_dir)}")
 
 
 @app.command("run")
 def run_cmd(
     quest: int = typer.Argument(..., help="Quest number (e.g. 3)"),
     year: int = typer.Option(datetime.now().year, "--year", "-y", help="Event year"),
-    part: int = typer.Option(1, "--part", "-p", help="Part number to execute"),
+    part: Literal[1, 2, 3] = typer.Option(
+        1, "--part", "-p", help="Part number to execute"
+    ),
 ) -> None:
     """Execute the solution for a given quest and part using input data."""
 
@@ -168,7 +179,9 @@ def run_cmd(
 def test_cmd(
     quest: int = typer.Argument(..., help="Quest number (e.g. 3)"),
     year: int = typer.Option(datetime.now().year, "--year", "-y", help="Event year"),
-    part: int = typer.Option(1, "--part", "-p", help="Part number to test"),
+    part: Literal[1, 2, 3] = typer.Option(
+        1, "--part", "-p", help="Part number to test"
+    ),
 ) -> None:
     """Run the solution for a given quest and part using test data."""
 
@@ -189,7 +202,9 @@ def test_cmd(
 def push_cmd(
     quest: int = typer.Argument(..., help="Quest number (e.g. 3)"),
     year: int = typer.Option(datetime.now().year, "--year", "-y", help="Event year"),
-    part: int = typer.Option(1, "--part", "-p", help="Part number to test"),
+    part: Literal[1, 2, 3] = typer.Option(
+        1, "--part", "-p", help="Part number to submit"
+    ),
 ) -> None:
     """Submit the solution for a given quest and part."""
 
@@ -206,9 +221,47 @@ def push_cmd(
     if result.get("correct"):
         typer.echo(
             f"✅ Correct answer for Quest {quest} Part {part}!"
-            f"\n🏅 - Global place: {result.get('globalPlace', '?')}"
-            f"\n⏱️ - Global time: {result.get('globalTime', '?')}"
+            f"\n - Global place: {result.get('globalPlace', '?')}"
+            f"\n - Global score: {result.get('globalScore', '?')}"
+            f"\n - Global time: {utils.format_duration(result.get('globalTime'))}"
+            f"\n - Local time: {utils.format_duration(result.get('localTime'))}"
         )
+
+        # Download the next part (if the quest is not ended)
+        if part == 3:
+            return
+        else:
+            typer.echo()
+
+        # Download the input for the given part
+        try:
+            input_dict = utils.download_input(year, quest)
+        except Exception as e:
+            typer.echo(f"❌ Failed to fetch input: {e}")
+            raise typer.Exit(1)
+
+        # Prepare directory structure
+        quest_dir = utils.create_quest_dir(base_dir, year, quest)
+
+        # 5. Save available inputs
+        input_file = quest_dir / f"input/input_p{part + 1}.txt"
+        if input_file.exists():
+            typer.echo(
+                f"⚠️ Input file for part {part + 1} already exists (use ecd pull --force to overwrite)."
+            )
+        else:
+            input_file.write_text(input_dict[str(part + 1)], encoding="utf-8")
+            typer.echo(f"📥 Saved input for quest {quest:02d} part {part + 1}.")
+
+        # 6. Ensure empty test file exists
+        test_file = quest_dir / f"test/test_p{part + 1}.txt"
+        if test_file.exists():
+            typer.echo(
+                f"⚠️ Test file for part {part + 1} already exists (use ecd pull --force to overwrite)."
+            )
+        else:
+            test_file.touch(exist_ok=True)
+
     else:
         typer.echo(
             f"❌ Incorrect answer for Quest {quest} Part {part}:"
